@@ -5,7 +5,7 @@ __author__ = "Camilo A. Ospina A."
 __copyright__ = "Copyright 2012-2014, Bogotá, Colombia"
 __credits__ = ["Camilo A. Ospina A."]
 __license__ = "MIT"
-__version__ = "PyTam 0.2.2"
+__version__ = "PyTam 0.3"
 __maintainer__ = "Camilo A. Ospina A."
 __email__ = "camilo.ospinaa@gmail.com"
 __status__ = "Testing"
@@ -27,8 +27,9 @@ elif osn in ("nt", "dos", "ce"): # DOS/Windows
     
 def createTWS(*args): 
     '''
-    creteTWS creates a table workspace and allows different ways of use, you can
-    choose the one that fits the best your needs.
+
+    creteTWS creates a table workspace and allows different ways of use,
+    you can choose the one that fits the best your needs.
     
     Method 1:
         By just executing the createTWS method you will get a new
@@ -36,12 +37,12 @@ def createTWS(*args):
         "pytam", this table workspace will be created on "./" .
         
         eg: createTWS()
-        
+
     Method 2:
         You can specify the location, name and password of the new table
-        workspace (always using forward slashes "/" to specify the location).
-        if you only specify the location and name of the table workspace the
-        password will be sent to blank ("").
+        workspace (always using forward slashes "/" to specify the
+        location).if you only specify the location and name of the table
+        workspace the password will be sent to blank ("").
 
         eg1:
             createTWS("/home/user", "TWS_1", "myPassword")
@@ -50,11 +51,12 @@ def createTWS(*args):
         eg2:
             createTWS("/home/user", "TWS_1")
             createTWS("C:/Users/user", "TWS_1")
-            
+           
     Method 3:
-        You can specify only the name and password. Using this method the
-        table workspace location will be on "./", and just like in the method 2
-        if you only specify the name the password will be set blank ("").
+        You can specify only the name and password. Using this method
+        the table workspace location will be on "./", and just like in
+        the method 2 if you only specify the name the password will be
+        set blank ("").
         
         eg1:
             createTWS("TWS_1", "myPassword")
@@ -175,8 +177,9 @@ def createTWS(*args):
             
 def useTWS(route, password,user=None,logs='disable'):
     '''
-    Return an object with the table workspace connection if the TWS exist and the password
-    matches with the one given otherwise raises an exception.
+    Return an object with the table workspace connection if the TWS
+    exist and the password matches with the one given otherwise raises
+    an exception.
     
     eg:
         tws=useTWS("/home/user/TWS1", "1234")
@@ -219,10 +222,11 @@ class connection():
         
     def createTable(self, name, columns):
         '''
-        createTable allows to create tables into a table workspace, by receiving
-        the name of the table and a dictionary with the fields names and data types.
-        The possible data types are: 'str', 'char', 'bool', 'float', 'int', 'date' and 'file' 
-        To specify the key field this must be preceded by a star "*".
+        createTable allows to create tables into a table workspace, by
+        receiving the name of the table and a dictionary with the fields
+        names and data types. The possible data types are: 'str', 'char',
+        'bool', 'float', 'int', 'date' and 'file'. To specify the key field
+        this must be preceded by a star "*".
         
         eg:
             tws.createTable('table1',{
@@ -249,7 +253,7 @@ class connection():
         columns_types=tuple(columns.values())
         
         for column_name in columns_names:
-            if '/' in column_name: raise Table_Problem("Columns names can't contain slashes '/'. ")            
+            if '/' in column_name: raise Table_Problem("Columns names can't contain slashes '/'. ")          
         for column_type in columns_types:
             if column_type not in types: raise Table_Problem("Columns type '%s' not supported. "%(column_type))   
             
@@ -289,11 +293,11 @@ class connection():
             
     def insertInto(self, table, values):
         '''
-        insertInto allows to add registries to an specified table by receiving the table name
-        and a dictionary with the fields and their corresponding values.
-        It's necessary that the key field is present to add a registry, and that all values
-        correspond to the data type of the field.
-        Date type fields must be on ISO 8601 format.
+        insertInto allows to add registries to an specified table by
+        receiving the table name and a dictionary with the fields and their
+        corresponding values. It's necessary that the key field is present
+        to add a registry, and that all values correspond to the data type
+        of the field. Date type fields must be on ISO 8601 format.
 
         eg:
             tws.insertInto('table1',{
@@ -399,7 +403,8 @@ class connection():
 
     def __getRegs(self,table):
         '''
-        __getRegs is a hidden method that returns all registries from a given table.
+        __getRegs is a hidden method that returns all registries from a
+        given table.
 
         '''
         from gzip import open as gopen
@@ -479,17 +484,19 @@ class connection():
 
     def fetchAll(self, *args):
         '''
-        fetchAll returns all registries from a table according to a set of filters, default
-        filter is None which return all registries from the given table.
+        fetchAll returns a list of lists with all registries from a
+        table according to a set of filters, default filter is None
+        which return all registries from the given table.
 
         eg1:
-            tws.fetchAll('table1')
+           tws.fetchAll('table1')
         eg2:
-            tws.fetchAll('table1', {'id':1})
+           tws.fetchAll('table1', {'id':1})
         eg3:
-            tws.fetchAll('table1', {'name':'name1', 'lastname':'lastName1'})
+           tws.fetchAll('table1', {'name':'name1', 'lastname':'lastName1'})
 
-        Registries order by an specific field ('d' is descending and 'a' is ascending)
+           Registries order by an specific field ('d' is descending and 'a'
+           is ascending)
 
         eg4: 
             tws.fetchAll('table1','name')
@@ -498,7 +505,9 @@ class connection():
         eg6:
 
             tws.fetchAll('table1', {'name':'name1'}, 'age','d')
-            this get all registries from table1 which name is 'name1' in a descending order by age.
+
+            this get all registries from table1 which name is 'name1'
+            in a descending order by age.
 
         '''
         pTypes=[]
@@ -655,10 +664,55 @@ class connection():
         for reg in regs: tree.insert(reg,orderBy)
         return tree.inorder(tree.root)
 
+
+    def fetchAsDict(self,*args):
+        '''
+        fetchAsDict returns a list of dictionaries with all registries from
+        a table according to a set of filters, default filter is None
+        which return all registries from the given table.
+
+        eg1:
+         tws.fetchAsDict('table1')
+
+        eg2:
+         tws.fetchAsDict('table1', {'id':1})
+
+        eg3:
+         tws.fetchAsDict('table1', {'name':'name1', 'lastname':'lastName1'})
+
+          Registries order by an specific field ('d' is descending and 'a'
+          is ascending)
+
+        eg4: 
+         tws.fetchAsDict('table1','name')
+
+        eg5:
+         tws.fetchAsDict('table1','name','d')
+
+        eg6:
+         tws.fetchAsDict('table1', {'name':'name1'}, 'age','d')
+
+         this get all registries from table1 which name is 'name1'
+         in a descending order by age.
+        '''
+
+        regs=self.fetchAll(*args)
+        fields=[x[0] if x[0][0]!="*" else x[0][1:] for x in self.getSchema(args[0])]
+        if fields==[]: return []
+        listOfDicts=[]
+        for reg in regs:
+            tmp={}
+            for field in range(len(fields)):
+                tmp[fields[field]]=reg[field]
+            listOfDicts.append(tmp)
+        return listOfDicts
+
+
+
     def deleteFrom(self, table, keyvalue):
         '''
-        deleteFrom, deletes a registry from a table, given the key value of the registry
-        to delete.
+        deleteFrom, deletes a registry from a table, given the key value
+        of the registry to delete.
         eg:
             tws.deleteFrom('table1','id1')
         '''
@@ -727,12 +781,14 @@ class connection():
 
     def updateFrom(self, table, keyvalue, values):
         '''
-        updateFrom allows to modify data from an existing registry. It works by receiving
-        the name of the table in which is located the registry, the Key Value of the registry
-        and finally a dictionary with the fields and values to modify.
+        updateFrom allows to modify data from an existing registry.
+        It works by receiving the name of the table in which is located the
+        registry, the Key Value of the registry and finally a dictionary
+        with the fields and values to modify.
 
         eg:
-            tws.updateFrom('table1', 'id1', {'name':'newName', 'lastname':'newLastname'})
+        tws.updateFrom('table1', 'id1',
+            {'name':'newName', 'lastname':'newLastname'})
 
         '''
         if table not in self.listTables(): raise Table_Problem("Table not found. ")
@@ -916,7 +972,8 @@ class connection():
 
     def match(self, keyvalue, tables):
         '''
-        match return all registries that matches between different tables given one key value.
+        match return all registries that matches between different tables
+        given one key value.
         eg:
             tws.match('id1', ['table1', 'table2', 'table3'])
         '''
@@ -946,6 +1003,9 @@ class connection():
         return res
 
     def __log(self, action):
+        '''
+        _log register an action on the log file
+        '''
         from datetime import date
         with open(self.tablesR+s+'logs'+s+str(date.today())+'.log','a') as f:
             f.write(self.user+': '+action+'\n')
@@ -997,4 +1057,4 @@ class BinaryTree():
             self.inorder(x.right)
         return self.res
 
-def Dtype(v):return str(type(v)).split("'")[1]
+def Dtype(v):return str(type(v)).split("'")[1]
\ No newline at end of file
